@@ -42,111 +42,111 @@ as.rimg <- function(object, name = "img") {
 #' @export
 #'
 as.rimg.default <- function(object, name = "img") {
-  if (!inherits(object, "rimg")) { # Not already 'rimg'
-
-    attrgiver <- function(x, name2 = name) {
-      # Attributes
-      class(x) <- c("rimg", "array")
-      attr(x, "state") <- "raw"
-      attr(x, "imgname") <- name2
-      attr(x, "px_scale") <- NA
-      attr(x, "raw_scale") <- NA
-      attr(x, "k") <- NA
-      attr(x, "outline") <- NA
-      attr(x, "colnames") <- NA
-      attr(x, "tag_loc") <- NA
-      x
-    }
-
-    rescaler <- function(x) {
-      if (any(x > 1)) {
-        message("Rescaling values to [0,1]")
-        for (i in seq_len(dim(x)[3])) {
-          x[, , i] <- x[, , i] / 255
-        }
-      }
-      x
-    }
-
-    # Control flow for multi-images
-    if (!inherits(object, "list")) {
-      object2 <- list(object)
-    } else {
-      object2 <- object
-    }
-
-    # Is it already colour-classified by the user?
-    # Tricky to distinguish between single-dimension (greyscale) RGB & a
-    # colour-classified matrix. Best I've got atm.
-    is.whole <- function(x) {
-      all(is.numeric(x), floor(x) == x)
-    }
-    if (inherits(object2[[1]], "matrix") && max(object2[[1]]) < 30 && is.whole(object2[[1]])) {
-      colclass <- TRUE
-    } else {
-      colclass <- FALSE
-    }
-
-    if (!colclass) {
-
-      # Array check
-      if (any(unlist(lapply(seq_along(object2), function(x) !is.array(object2[[x]]))))) {
-        stop("Images must be an array.")
-      }
-
-      # Duplicate channels if grayscale
-      for (i in seq_along(object2)) {
-        if (is.na(dim(object2[[i]])[3])) {
-          object2[[i]] <- replicate(3, object2[[i]], simplify = "array")
-        }
-      }
-
-      # 3D maximum
-      object2 <- lapply(seq_along(object2), function(j) object2[[j]][, , 1:3])
-
-      # Rescale RGB to [0,1] if need be
-      object2 <- lapply(seq_along(object2), function(j) rescaler(object2[[j]]))
-
-      # Attributes
-      if (length(name) == 1) {
-        name <- rep(name, length(object2))
-      }
-      object2 <- lapply(seq_along(object2), function(j) attrgiver(object2[[j]], name[[j]]))
-
-      # The list itself needs attributes
-      class(object2) <- c("rimg", "list")
-      attr(object2, "state") <- "raw"
-    } else if (colclass) {
-
-      # Attributes
-      if (length(name) == 1) {
-        name <- rep(name, length(object2))
-      }
-      object2 <- lapply(seq_along(object2), function(j) attrgiver(object2[[j]], name[[j]])) # names
-      for (i in seq_along(object2)) attr(object2[[i]], "state") <- "colclass" # classification state
-      for (i in seq_along(object2)) attr(object2[[i]], "k") <- length(table(object2[[i]])) # kcols
-      for (i in seq_along(object2)) attr(object2[[i]], "class") <- c("rimg", "matrix") # class
-      for (i in seq_along(object2)) attr(object2[[i]], "colnames") <- data.frame(name = seq_along(table(object2[[i]]))) # colour-category names (in progress)
-      for (i in seq_along(object2)) {
-        attr(object2[[i]], "classRGB") <- data.frame(
-          R = rep(NA, length(table(object2[[i]]))),
-          G = rep(NA, length(table(object2[[i]]))),
-          B = rep(NA, length(table(object2[[i]])))
-        )
-      }
-      # The list itself needs attributes
-      class(object2) <- c("rimg", "list")
-      attr(object2, "state") <- "colclass"
-    }
-    # Output
-    if (!inherits(object, "list") || length(object) == 1) {
-      object2[[1]]
-    } else {
-      object2
-    }
+  if (is.rimg(object)) {
     # Just output the original, if already 'rimg'
+    return(object)
+  }
+
+  attrgiver <- function(x, name2 = name) {
+    # Attributes
+    class(x) <- c("rimg", "array")
+    attr(x, "state") <- "raw"
+    attr(x, "imgname") <- name2
+    attr(x, "px_scale") <- NA
+    attr(x, "raw_scale") <- NA
+    attr(x, "k") <- NA
+    attr(x, "outline") <- NA
+    attr(x, "colnames") <- NA
+    attr(x, "tag_loc") <- NA
+    x
+  }
+
+  rescaler <- function(x) {
+    if (any(x > 1)) {
+      message("Rescaling values to [0,1]")
+      x <- x / 255
+    }
+    x
+  }
+
+  # Control flow for multi-images
+  if (!inherits(object, "list")) {
+    object2 <- list(object)
   } else {
-    object
+    object2 <- object
+  }
+
+  # Is it already colour-classified by the user?
+  # Tricky to distinguish between single-dimension (greyscale) RGB & a
+  # colour-classified matrix. Best I've got atm.
+
+  # Function copied from ?integer help page
+  is.whole <- function(x, tol = .Machine$double.eps^0.5) {
+    all(abs(x - round(x)) < tol)
+  }
+
+  if (inherits(object2[[1]], "matrix") && max(object2[[1]]) < 30 && is.whole(object2[[1]])) {
+    colclass <- TRUE
+  } else {
+    colclass <- FALSE
+  }
+
+  if (!colclass) {
+
+    # Array check
+    if (any(unlist(lapply(seq_along(object2), function(x) !is.array(object2[[x]]))))) {
+      stop("Images must be an array.")
+    }
+
+    # Duplicate channels if grayscale
+    for (i in seq_along(object2)) {
+      if (is.na(dim(object2[[i]])[3])) {
+        object2[[i]] <- replicate(3, object2[[i]], simplify = "array")
+      }
+    }
+
+    # 3D maximum
+    object2 <- lapply(seq_along(object2), function(j) object2[[j]][, , 1:3])
+
+    # Rescale RGB to [0,1] if need be
+    object2 <- lapply(object2, rescaler)
+
+    # Attributes
+    if (length(name) == 1) {
+      name <- rep(name, length(object2))
+    }
+    object2 <- lapply(seq_along(object2), function(j) attrgiver(object2[[j]], name[[j]]))
+
+    # The list itself needs attributes
+    class(object2) <- c("rimg", "list")
+    attr(object2, "state") <- "raw"
+  } else { # colour classified object
+
+    # Attributes
+    if (length(name) == 1) {
+      name <- rep(name, length(object2))
+    }
+    object2 <- lapply(seq_along(object2), function(j) attrgiver(object2[[j]], name[[j]])) # names
+    for (i in seq_along(object2)) {
+      attr(object2[[i]], "state") <- "colclass" # classification state
+      attr(object2[[i]], "k") <- length(table(object2[[i]])) # kcols
+      attr(object2[[i]], "class") <- c("rimg", "matrix") # class
+      attr(object2[[i]], "colnames") <- data.frame(name = seq_along(table(object2[[i]]))) # colour-category names (in progress)
+      attr(object2[[i]], "classRGB") <- data.frame(
+        R = rep(NA, length(table(object2[[i]]))),
+        G = rep(NA, length(table(object2[[i]]))),
+        B = rep(NA, length(table(object2[[i]])))
+      )
+    }
+    # The list itself needs attributes
+    class(object2) <- c("rimg", "list")
+    attr(object2, "state") <- "colclass"
+  }
+  # Output
+  if (!inherits(object, "list") || length(object) == 1) {
+    object2[[1]]
+  } else {
+    object2
   }
 }
 
@@ -184,7 +184,6 @@ is.rimg <- function(object) {
 #' contains a suite of useful image-processing capabilities.
 #'
 #' @param image an object of class `rimg`
-#' @inheritParams as.rimg
 #'
 #' @return an image of the specified class
 #'
