@@ -6,7 +6,8 @@
 #' @param vismodeldata (required) quantum catch color data. Can be either the result
 #'  from [vismodel()] or independently calculated data (in the form of a
 #'  data frame with three columns representing trichromatic viewer).
-#' @param space (required) Choice between XYZ (1931), LAB (1971), or LCh colour models.
+#' @param space (required) Choice between XYZ (default), LAB, or LCh colour models.
+#'
 #'
 #' @return Object of class [`colspace`] containing:
 #' * `X, Y, Z`: Tristimulus values.
@@ -43,16 +44,16 @@
 #'  Internationale de l Eclairage.
 
 cie <- function(vismodeldata, space = c("XYZ", "LAB", "LCh")) {
-  space2 <- try(match.arg(space), silent = TRUE)
-  if (inherits(space2, "try-error")) {
-    space <- "XYZ"
-  }
+  space <- tryCatch(match.arg(space),
+    error = function(e) {
+      message("Invalid space arg. Defaulting to XYZ")
+      return("XYZ")
+    }
+  )
 
-  dat <- vismodeldata
-
-  X <- dat[, names(dat) %in% c("X", "cie2_X", "cie10_X")]
-  Y <- dat[, names(dat) %in% c("Y", "cie2_Y", "cie10_Y")]
-  Z <- dat[, names(dat) %in% c("Z", "cie2_Z", "cie10_Z")]
+  X <- vismodeldata[, names(vismodeldata) %in% c("X", "cie2_X", "cie10_X")]
+  Y <- vismodeldata[, names(vismodeldata) %in% c("Y", "cie2_Y", "cie10_Y")]
+  Z <- vismodeldata[, names(vismodeldata) %in% c("Z", "cie2_Z", "cie10_Z")]
 
   # Coordinates in the chosen CIE space
   if (space == "XYZ") {
@@ -63,8 +64,8 @@ cie <- function(vismodeldata, space = c("XYZ", "LAB", "LCh")) {
 
     # Calculate tristimulus values for neutral point. First need to
     # re-grab original sensitivity and illuminant data.
-    S <- attr(dat, "data.visualsystem.chromatic")
-    illum <- attr(dat, "data.illuminant") # Illuminant
+    S <- attr(vismodeldata, "data.visualsystem.chromatic")
+    illum <- attr(vismodeldata, "data.illuminant") # Illuminant
     Xn <- sum(S[, 1] * illum)
     Yn <- sum(S[, 2] * illum)
     Zn <- sum(S[, 3] * illum)
@@ -101,15 +102,13 @@ cie <- function(vismodeldata, space = c("XYZ", "LAB", "LCh")) {
   }
 
   if (space == "XYZ") {
-    res.p <- data.frame(X, Y, Z, x, y, z, row.names = rownames(dat))
+    res <- data.frame(X, Y, Z, x, y, z, row.names = rownames(vismodeldata))
   } else if (space == "LAB") {
-    res.p <- data.frame(X, Y, Z, L, a, b, row.names = rownames(dat))
+    res <- data.frame(X, Y, Z, L, a, b, row.names = rownames(vismodeldata))
   } else if (space == "LCh") {
-    res.p <- data.frame(X, Y, Z, L, a, b, C, h, row.names = rownames(dat))
+    res <- data.frame(X, Y, Z, L, a, b, C, h, row.names = rownames(vismodeldata))
   }
 
-  res <- res.p
-
   class(res) <- c("colspace", "data.frame")
 
   # Descriptive attributes (largely preserved from vismodel)
