@@ -1,70 +1,82 @@
 #' Colour distances
 #'
-#' Calculates colour distances. When data are the result of [vismodel()],
-#' it applies the receptor-noise model of Vorobyev et al. (1998) to calculate colour distances
-#' with noise based on relative photoreceptor densities. It also accepts [colspace()] data in which case
-#' unweighted Euclidean distances or Manhattan distances (coc model only) are returned.
+#' Calculates colour distances. When data are the result of [vismodel()], it
+#' applies the receptor-noise model of Vorobyev et al. (1998) to calculate
+#' colour distances with noise based on relative photoreceptor densities. It
+#' also accepts [colspace()] data in which case unweighted Euclidean distances
+#' or Manhattan distances (coc model only) are returned.
 #'
-#' @param modeldata (required) quantum catch colour data. Can be the result
-#'  from [vismodel()] for noise-weighted Euclidean distances, or [colspace()] for
-#'  unweighted (typically) Euclidean distances. Data may also be independently calculated
-#'  quantum catches, in the form of a data frame with columns representing photoreceptors.
-#' @param qcatch if the object is of class [`vismodel`] or [`colspace`],
-#'  this argument is ignored. If the object is a data frame of quantal catches
-#'  from another source, this argument is used to specify what type of quantum catch is being
-#'  used, so that the noise can be calculated accordingly:
-#'  * `Qi`: Quantum catch for each photoreceptor
-#'  * `fi`: Quantum catch according to Fechner's law (the signal of the receptor
-#'  channel is proportional to the logarithm of the quantum catch)
-#' @param subset If only some of the comparisons should be returned, a character vector of
-#'  length 1 or 2 can be provided, indicating which samples are desired. The subset vector
-#'  must match the labels of the input samples, but partial matching (and regular expressions)
-#'  are supported.
-#' @param achromatic Logical. If `TRUE`, last column of the data frame is used to calculate
-#'  the achromatic contrast, the form of which will depend on the input data and will be
-#'  indicated by a message during execution. For noise-weighted distances, noise is based on
-#'  the Weber fraction given by the argument `weber.achro`.
-#' @param n photoreceptor densities for the cones used in visual modeling.
-#'  must have same length as number of columns (excluding achromatic receptor if used;
-#'  defaults to the Pekin robin *Leiothrix lutea* densities: `c(1,2,2,4)`).
-#'  Ignored for [`colspace`] objects.
-#' @param weber The Weber fraction to be used (often also referred to as receptor noise,
-#'  or *e*). The noise-to-signal ratio `v` is unknown,
-#'  and therefore must be calculated based on the empirically estimated Weber
-#'  fraction of one of the cone classes. `v` is then applied to estimate the
-#'  Weber fraction of the other cones. by default, the value of 0.1 is used
-#'  (the empirically estimated value for the
-#'  LWS cone from *Leiothrix lutea*). See Olsson et al. 2017 for a review of
-#'  published values in the literature. Ignored for `colspace` objects.
+#' @param modeldata (required) quantum catch colour data. Can be the result from
+#'   [vismodel()] for noise-weighted Euclidean distances, or [colspace()] for
+#'   unweighted (typically) Euclidean distances. Data may also be independently
+#'   calculated quantum catches, in the form of a data frame with columns
+#'   representing photoreceptors.
+#' @param qcatch if the object is of class [`vismodel`] or [`colspace`], this
+#'   argument is ignored. If the object is a data frame of quantal catches from
+#'   another source, this argument is used to specify what type of quantum catch
+#'   is being used, so that the noise can be calculated accordingly: * `Qi`:
+#'   Quantum catch for each photoreceptor * `fi`: Quantum catch according to
+#'   Fechner's law (the signal of the receptor channel is proportional to the
+#'   logarithm of the quantum catch)
+#' @param subset If only some of the comparisons should be returned, a character
+#'   vector of length 1 or 2 can be provided, indicating which samples are
+#'   desired. The subset vector must match the labels of the input samples, but
+#'   partial matching (and regular expressions) are supported.
+#' @param achromatic Logical. If `TRUE`, last column of the data frame is used
+#'   to calculate the achromatic contrast, the form of which will depend on the
+#'   input data and will be indicated by a message during execution. For
+#'   noise-weighted distances, noise is based on the Weber fraction given by the
+#'   argument `weber.achro`.
+#' @param n photoreceptor densities for the cones used in visual modeling. must
+#'   have same length as number of columns (excluding achromatic receptor if
+#'   used; defaults to the Pekin robin *Leiothrix lutea* densities:
+#'   `c(1,2,2,4)`). Ignored for [`colspace`] objects.
+#' @param weber The Weber fraction(s) to be used (often also referred to as
+#'   receptor noise, or *e*). The noise-to-signal ratio `v` is unknown, and
+#'   therefore must be calculated based on the empirically estimated Weber
+#'   fraction of one or (more rarely) all the cone classes. When noise is only
+#'   known for one receptor, as is typical, `v` is then applied to estimate the
+#'   Weber fraction of the other cones. By default, the value of 0.1 is used
+#'   (the empirically estimated value for the LWS cone from *Leiothrix lutea*).
+#'   See Olsson et al. 2017 for a review of published values in the literature.
+#'   Ignored for `colspace` objects.
 #' @param weber.ref the cone class used to obtain the empirical estimate of the
-#'  Weber fraction used for the `weber` argument. By default, `n4` is used,
-#'  representing the LWS cone for *Leiothrix lutea*. Ignored for `colspace` objects.
-#' @param weber.achro the Weber fraction to be used to calculate achromatic contrast, when
-#'  `achromatic = TRUE`. Defaults to 0.1. Ignored for `colspace` objects.
-#' @param noise how the noise will be calculated (ignored for `colspace` objects):
-#' * `neural` (default): noise is proportional to the Weber fraction and
-#'  is independent of the intensity of the signal received (i.e. assumes bright conditions).
-#' * `quantum`: noise is the sum of the neural noise and receptor noise,
-#'  and is thus proportional to the Weber fraction and inversely proportional
-#'  to the intensity of the signal received (the quantum catches).
-#'  Note that the `quantum` option will only work with
-#' objects of class `vismodel`.
+#'   Weber fraction used for the `weber` argument, if a single value is
+#'   specified. By default, `n4` is used, representing the LWS cone for
+#'   *Leiothrix lutea*. Ignored for `colspace` objects.
+#' @param weber.achro the Weber fraction to be used to calculate achromatic
+#'   contrast, when `achromatic = TRUE`. Defaults to 0.1. Ignored for `colspace`
+#'   objects.
+#' @param noise how the noise will be calculated (ignored for `colspace`
+#'   objects):
+#'   * `neural` (default): noise is proportional to the Weber fraction and is
+#'   independent of the intensity of the signal received (i.e. assumes bright
+#'   conditions).
+#'   * `quantum`: noise is the sum of the neural noise and receptor noise, and
+#'   is thus proportional to the Weber fraction and inversely proportional to
+#'   the intensity of the signal received (the quantum catches).
+#'   Note that the `quantum` option will only work with objects of
+#'   class `vismodel`.
 #'
-#' @return A data frame containing up to 4 columns.
-#' The first two (`patch1, patch2`) refer
-#' to the two colors being contrasted; `dS` is the chromatic contrast (delta S)
-#' and `dL` is the achromatic contrast (delta L). Units of `dS` JND's in the receptor-noise
-#' model, unweighted Euclidean distances in colorspace models, and Manhattan distances in the
-#' color-opponent-coding space. Units of `dL` vary, and are either simple contrast, Weber contrast,
-#' or Michelson contrast, as indicated by the output message.
+#' @return A data frame containing up to 4 columns. The first two
+#'   (`patch1, patch2`) refer to the two colors being contrasted; `dS` is the
+#'   chromatic contrast (delta S) and `dL` is the achromatic contrast (delta L).
+#'   Units of `dS` JND's in the receptor-noise model, unweighted Euclidean
+#'   distances in colorspace models, and Manhattan distances in the
+#'   colour-opponent-coding space. Units of `dL` vary, and are either simple
+#'   contrast, Weber contrast, or Michelson contrast, as indicated by the output
+#'   message.
 #'
-#' @section Note on previous versions: Generic di- tri- and tetra-chromatic `colspace()` objects were previously
-#' passed through the receptor-noise limited model to return noise-weighted Euclidean distances. This 
-#' behaviour has been amended, and generic spaces now return unweighted Euclidean distances. Equivalent 
-#' results to the former behaviour can be attained by sending the results of `vismodel()` directly to `coldist()`
-#' , as previously, which also offers greater flexibility and reliability. Thus `coldist()` now returns
-#'  unweighted Euclidean distances for `colspace()` objects (with the exception of Manhattan distances for 
-#'  the coc space), and noise-weighted Euclidean distances for `vismodel()` objects.   
+#' @section Note on previous versions: Generic di- tri- and tetra-chromatic
+#'   `colspace` objects were previously passed through the receptor-noise
+#'   limited model to return noise-weighted Euclidean distances. This behaviour
+#'   has been amended, and generic spaces now return unweighted Euclidean
+#'   distances. Equivalent results to the former behaviour can be attained by
+#'   sending the results of [vismodel()] directly to [coldist()] , as
+#'   previously, which also offers greater flexibility and reliability. Thus
+#'   [coldist()] now returns unweighted Euclidean distances for `colspace`
+#'   objects (with the exception of Manhattan distances for the coc space), and
+#'   noise-weighted Euclidean distances for `vismodel` objects.
 #'
 #' @export
 #'
@@ -96,26 +108,28 @@
 #' data(sicalis)
 #' vis.sicalis <- vismodel(sicalis, visual = "avg.uv", relative = FALSE)
 #' tetradist.sicalis.n <- coldist(vis.sicalis)
-#' 
 #' }
 #'
 #' @author Rafael Maia \email{rm72@@zips.uakron.edu}
 #'
-#' @references Vorobyev, M., Osorio, D., Bennett, A., Marshall, N., & Cuthill, I.
-#'  (1998). Tetrachromacy, oil droplets and bird plumage colours. Journal Of Comparative
-#'  Physiology A-Neuroethology Sensory Neural And Behavioral Physiology, 183(5), 621-633.
-#' @references Hart, N. S. (2001). The visual ecology of avian photoreceptors. Progress
-#'  In Retinal And Eye Research, 20(5), 675-703.
-#' @references Endler, J. A., & Mielke, P. (2005). Comparing entire colour patterns
-#'  as birds see them. Biological Journal Of The Linnean Society, 86(4), 405-431.
+#' @references Vorobyev, M., Osorio, D., Bennett, A., Marshall, N., & Cuthill,
+#'   I. (1998). Tetrachromacy, oil droplets and bird plumage colours. Journal Of
+#'   Comparative Physiology A-Neuroethology Sensory Neural And Behavioral
+#'   Physiology, 183(5), 621-633.
+#' @references Hart, N. S. (2001). The visual ecology of avian photoreceptors.
+#'   Progress In Retinal And Eye Research, 20(5), 675-703.
+#' @references Endler, J. A., & Mielke, P. (2005). Comparing entire colour
+#'   patterns as birds see them. Biological Journal Of The Linnean Society,
+#'   86(4), 405-431.
 #' @references Olsson, P., Lind, O., & Kelber, A. (2015) Bird colour vision:
-#'  behavioural thresholds reveal receptor noise. Journal of Experimental Biology,
-#'  218, 184-193.
-#' @references Lind, O. (2016) Colour vision and background adaptation in a passerine
-#'  bird, the zebra finch (Taeniopygia guttata). Royal Society Open Science, 3, 160383.
-#' @references Olsson, P., Lind, O., & Kelber, A. (2017) Chromatic and achromatic
-#'  vision: parameter choice and limitations for reliable model predictions.
-#'  Behavioral Ecology, \doi{10.1093/beheco/arx133}
+#'   behavioural thresholds reveal receptor noise. Journal of Experimental
+#'   Biology, 218, 184-193.
+#' @references Lind, O. (2016) Colour vision and background adaptation in a
+#'   passerine bird, the zebra finch (Taeniopygia guttata). Royal Society Open
+#'   Science, 3, 160383.
+#' @references Olsson, P., Lind, O., & Kelber, A. (2017) Chromatic and
+#'   achromatic vision: parameter choice and limitations for reliable model
+#'   predictions. Behavioral Ecology, \doi{10.1093/beheco/arx133}
 
 
 coldist <- function(modeldata,
@@ -167,7 +181,7 @@ coldist <- function(modeldata,
     # Convert lum values to 0 instead of NA, for convenient
     # processing. Converted back to NA at the end.
     if (attr(modeldata, "visualsystem.achromatic") == "none" && !(any(c("CIELAB", "CIELCh") %in% attr(modeldata, "clrsp")))
-        || is.null(attr(modeldata, "visualsystem.achromatic"))) {
+    || is.null(attr(modeldata, "visualsystem.achromatic"))) {
       modeldata$lum <- 0
       if (achromatic) {
         warning("achromatic = TRUE but visual model was calculated with achromatic = ",
@@ -218,9 +232,9 @@ coldist <- function(modeldata,
     # - vismodel object: always
     # - user input data: always
 
-    note_dS <- 'Calculating noise-weighted Euclidean distances'
+    note_dS <- "Calculating noise-weighted Euclidean distances"
     note_dL <- NULL
-    
+
     dat <- as.matrix(modeldata)
     rownames(dat) <- rownames(modeldata)
     colnames(dat) <- colnames(modeldata)
@@ -301,36 +315,40 @@ coldist <- function(modeldata,
     )
 
     if (achromatic) {
-      note_dL <- ' and noise-weighted luminance contrasts'
+      note_dL <- " and noise-weighted luminance contrasts"
       visref <- cbind(visref, lum = log(1e-10))
       visref[grep("jnd2xyzrrf", rownames(visref), invert = TRUE), "lum"] <-
         dat[seq(refsamp), dim(dat)[2]]
 
       res[, "dL"] <- switch(noise,
-        "neural" = unlist(lapply(seq(nrow(res)), function(x)
+        "neural" = unlist(lapply(seq(nrow(res)), function(x) {
           ttdistcalcachro(
             dat[res[x, 1], ], dat[res[x, 2], ],
             NULL, NULL, weber.achro
-          ))),
-        "quantum" = unlist(lapply(seq(nrow(res)), function(x)
+          )
+        })),
+        "quantum" = unlist(lapply(seq(nrow(res)), function(x) {
           ttdistcalcachro(
             dat[res[x, 1], ], dat[res[x, 2], ],
             qndat[res[x, 1], ], qndat[res[x, 2], ], weber.achro
-          )))
+          )
+        }))
       )
 
       resref[, "dL"] <- switch(noise,
-        "neural" = unlist(lapply(seq(nrow(resref)), function(x)
+        "neural" = unlist(lapply(seq(nrow(resref)), function(x) {
           ttdistcalcachro(
             visref[resref[x, 1], ], visref[resref[x, 2], ],
             NULL, NULL,
             weber.achro = weber.achro
-          ))),
-        "quantum" = unlist(lapply(seq(nrow(resref)), function(x)
+          )
+        })),
+        "quantum" = unlist(lapply(seq(nrow(resref)), function(x) {
           ttdistcalcachro(
             visref[resref[x, 1], ], visref[resref[x, 2], ],
             exp(visref)[resref[x, 1], ], exp(visref)[resref[x, 2], ], weber.achro
-          )))
+          )
+        }))
       )
 
       if (dim(dat)[2] <= ncone) {
@@ -374,21 +392,21 @@ coldist <- function(modeldata,
         "hexagon" = " and simple luminance contrast",
         "segment" = " and Michelson luminance contrast",
         "CIELAB" = ,
-        "CIELCh" = " and Weber luminance contrast",
         "categorical" = ,
-        "coc" = " and no luminance contrast"
+        "coc" = ,
+        "CIELCh" = " and Weber luminance contrast",
       )
 
       res[, "dL"] <- switch(attr(modeldata, "clrsp"),
         "dispace" = ,
         "trispace" = ,
-        "tcs" = apply(pairsid, 1, function(x) lumcont(dat[x[1], "lum"], dat[x[2], "lum"], type = "weber")),
-        "categorical" = NA,
-        "hexagon" = apply(pairsid, 1, function(x) lumcont(dat[x[1], "l"], dat[x[2], "l"], type = "simple")),
+        "categorical" = ,
+        "coc" = ,
+        "tcs" = lumcont(dat[pairsid[, 1], "lum"], dat[pairsid[, 2], "lum"], type = "weber"),
+        "hexagon" = lumcont(dat[pairsid[, 1], "l"], dat[pairsid[, 2], "l"], type = "simple"),
         "CIELAB" = ,
-        "CIELCh" = apply(pairsid, 1, function(x) lumcont(dat[x[1], "L"], dat[x[2], "L"], type = "weber")),
-        "segment" = apply(pairsid, 1, function(x) lumcont(dat[x[1], "B"], dat[x[2], "B"], type = "michelson")),
-        "coc" = NA
+        "CIELCh" = lumcont(dat[pairsid[, 1], "L"], dat[pairsid[, 2], "L"], type = "weber"),
+        "segment" = lumcont(dat[pairsid[, 1], "B"], dat[pairsid[, 2], "B"], type = "michelson")
       )
     }
     message(note_dS, note_dL)
@@ -444,7 +462,11 @@ coldist <- function(modeldata,
 
 newreceptornoise <- function(dat, n, weber, weber.ref, res, qndat = NULL) {
   reln <- n / sum(n)
-  v <- weber * sqrt(reln[weber.ref])
+  if (length(weber) == length(n)) { # For when weber is known for all receptors
+    v <- weber * sqrt(reln)
+  } else {
+    v <- weber * sqrt(reln[weber.ref])
+  } # When weber is known for one receptor (typical)
 
   if (is.null(qndat)) {
     e <- setNames(v / sqrt(reln), colnames(dat))
@@ -469,8 +491,9 @@ newreceptornoise <- function(dat, n, weber, weber.ref, res, qndat = NULL) {
     )
   } else {
     # get those combinations of ei and prod(ei)^2
-    num1 <- do.call("rbind", lapply(1:dim(res)[1], function(z)
-      apply(n1combs, 2, function(x) prod(e[z, x]))))
+    num1 <- do.call("rbind", lapply(1:dim(res)[1], function(z) {
+      apply(n1combs, 2, function(x) prod(e[z, x]))
+    }))
     colnames(num1) <- apply(n1combs, 2, paste, collapse = "")
   }
 
@@ -478,9 +501,11 @@ newreceptornoise <- function(dat, n, weber, weber.ref, res, qndat = NULL) {
   n2combs <- apply(n1combs, 2, function(x) colnames(dat)[ !colnames(dat) %in% x ])
 
   # f_d and f_e
-  deltaqiqj <- lapply(1:dim(n1combs)[2], function(y)
-    t(apply(res, 1, function(x)
-      dat[x[1], n2combs[, y]] - dat[x[2], n2combs[, y]])))
+  deltaqiqj <- lapply(1:dim(n1combs)[2], function(y) {
+    t(apply(res, 1, function(x) {
+      dat[x[1], n2combs[, y]] - dat[x[2], n2combs[, y]]
+    }))
+  })
   names(deltaqiqj) <- apply(n2combs, 2, paste, collapse = "")
 
   # (f_d-f_e)^2
@@ -510,8 +535,9 @@ newreceptornoise <- function(dat, n, weber, weber.ref, res, qndat = NULL) {
     )
     denominator <- sum(den^2)
   } else {
-    den <- do.call("rbind", lapply(1:dim(res)[1], function(z)
-      apply(dcombs, 2, function(x) prod(e[z, x]))))
+    den <- do.call("rbind", lapply(1:dim(res)[1], function(z) {
+      apply(dcombs, 2, function(x) prod(e[z, x]))
+    }))
     colnames(den) <- apply(dcombs, 2, paste, collapse = "")
     denominator <- rowSums(den^2)
   }
@@ -545,8 +571,8 @@ lumcont <- function(coord1, coord2, type = c("simple", "weber", "michelson")) {
 
   dLout <- switch(contrast,
     "simple" = coord1 / coord2,
-    "weber" = (max(c(coord1, coord2)) - min(c(coord1, coord2))) / min(c(coord1, coord2)),
-    "michelson" = (max(c(coord1, coord2)) - min(c(coord1, coord2))) / (max(c(coord1, coord2)) + min(c(coord1, coord2)))
+    "weber" = (pmax(coord1, coord2) - pmin(coord1, coord2)) / pmin(coord1, coord2),
+    "michelson" = (pmax(coord1, coord2) - pmin(coord1, coord2)) / (pmax(coord1, coord2) + pmin(coord1, coord2))
   )
   dLout
 }
