@@ -2,13 +2,14 @@
 #'
 #' Produces a colour hexagon plot.
 #'
-#' @param hexdata (required) a data frame, possibly a result from the [colspace()]
-#'  or [hexagon()]
-#'  function, containing values for the 'x' and 'y' coordinates as columns (labeled as such)
+#' @param hexdata (required) a data frame, possibly a result from the
+#'   [colspace()] or [hexagon()] function, containing values for the 'x' and 'y'
+#'   coordinates as columns (labeled as such)
 #' @param sectors plot the bee-hue sector dividers? Options are:
 #' * `"none"`: No sectors (default)
 #' * `"fine"`: 36 10-degree sectors
-#' * `"coarse"`: six bee-hue sectors (blue, blue-green, green, uv-green, uv, uv-blue).
+#' * `"coarse"`: six bee-hue sectors (blue, blue-green, green, uv-green, uv,
+#' uv-blue).
 #' @param sec.col line colour of hue sector dividers. Defaults to `"grey"`.
 #' @inheritParams triplot
 #'
@@ -58,13 +59,13 @@ hexplot <- function(hexdata, achro = TRUE, labels = TRUE,
   }
 
   # Hexagon edge coordinates
-  hexX <- c(0, -0.886, -0.886, 0, 0.886, 0.886, 0)
-  hexY <- c(1, 0.5, -0.5, -1, -0.5, 0.5, 1)
+  hexX <- c(0, -0.886, -0.886, 0, 0.886, 0.886)
+  hexY <- c(1, 0.5, -0.5, -1, -0.5, 0.5)
 
   # Hue sector divider coordinates
   # Coarse (45-degree)
-  secX <- c(0.886, -0.886, 0.4429999, -0.4429999, 0.4429999, -0.4429999, 0.886)
-  secY <- c(0, 0, 0.75, -0.75, -0.75, 0.75, 0)
+  secX <- c(0.886, -0.886, 0.4429999, -0.4429999, 0.4429999, -0.4429999)
+  secY <- c(0, 0, 0.75, -0.75, -0.75, 0.75)
 
   # Fine (10-degree)
   secX_c <- c(
@@ -96,21 +97,15 @@ hexplot <- function(hexdata, achro = TRUE, labels = TRUE,
   }
 
   # Hexagon outline
-  for (x in seq_along(hexX)) {
-    segments(hexX[x], hexY[x], hexX[x + 1], hexY[x + 1], lwd = out.lwd, col = out.lcol, lty = out.lty)
-  }
+  polygon(hexX, hexY, lwd = out.lwd, border = out.lcol, lty = out.lty)
 
   # Hexagon sectors
   if (sectors == "coarse") {
-    for (x in seq_along(secX)) {
-      segments(0, 0, secX[x], secY[x], col = sec.col)
-    }
+    segments(0, 0, secX, secY, col = sec.col)
   }
 
   if (sectors == "fine") {
-    for (x in seq_along(secX_c)) {
-      segments(0, 0, secX_c[x], secY_c[x], col = sec.col)
-    }
+    segments(0, 0, secX_c, secY_c, col = sec.col)
   }
 
   # remove plot-specific args, add points after the stuff is drawn
