@@ -1,5 +1,5 @@
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage("Welcome to pavo 2! Take a look at the latest features (and update your bibliography) in our recent publication: Maia R., Gruson H., Endler J. A., White T. E. (2019) pavo 2: new tools for the spectral and spatial analysis of colour in R. Methods in Ecology and Evolution, Early View.")
+  packageStartupMessage("Welcome to pavo 2! Take a look at the latest features (and update your bibliography) in our recent publication: Maia R., Gruson H., Endler J. A., White T. E. (2019) pavo 2: new tools for the spectral and spatial analysis of colour in R. Methods in Ecology and Evolution, 10, 1097-1107.")
 }
 
 #####################
@@ -7,9 +7,18 @@
 #####################
 
 huedisp <- function(tcsres) {
-  combn(nrow(tcsres), 2, function(x)
-    acos((cos(tcsres[x[1], "h.phi"]) * cos(tcsres[x[2], "h.phi"]) * cos(tcsres[x[1], "h.theta"] -
-      tcsres[x[2], "h.theta"])) + (sin(tcsres[x[1], "h.phi"]) * sin(tcsres[x[2], "h.phi"]))))
+  if (nrow(tcsres) == 1) {
+    return(NA)
+  }
+  # This function can probably also be expressed with x,y,z or u,s,m,l, which
+  # might help write a more efficient code using linear algebra libs.
+  alphas <- combn(nrow(tcsres), 2, function(x) {
+    phi <- tcsres[x, "h.phi"]
+    theta <- tcsres[x, "h.theta"]
+
+    prod(cos(phi), cos(diff(theta))) + prod(sin(phi))
+  })
+  acos(alphas)
 }
 
 
@@ -19,8 +28,9 @@ tcssum <- function(tcsres) {
   centroid <- colMeans(tcsres[c("u", "s", "m", "l")])
 
   # color span
-  colspan.m <- mean(dist(tcsres[, c("x", "y", "z")]))
-  colspan.v <- var(dist(tcsres[, c("x", "y", "z")]))
+  colspan <- dist(tcsres[, c("x", "y", "z")])
+  colspan.m <- mean(colspan)
+  colspan.v <- var(colspan)
 
   if (nrow(tcsres) > 3) {
     # color volume
@@ -38,8 +48,9 @@ tcssum <- function(tcsres) {
   }
 
   # hue disparity
-  hdisp.m <- mean(huedisp(tcsres))
-  hdisp.v <- var(huedisp(tcsres))
+  hdisp <- huedisp(tcsres)
+  hdisp.m <- mean(hdisp)
+  hdisp.v <- var(hdisp)
 
   # summary of achieved chroma
   mean.ra <- mean(tcsres$r.achieved)
