@@ -80,7 +80,7 @@ jndrot <- function(jnd2xyzres, center = c("mean", "achro"), ref1 = "l", ref2 = "
     aa <- vectornorm(coords[grep(paste0("jnd2xyzrrf.", ref1), rownames(coords)), ] -
       cent)
     bb <- vectornorm(axis1)
-    daabb <- sum(aa * bb)
+    daabb <- drop(crossprod(aa, bb))
     ncaabb <- vectormag(vectorcross(aa, bb))
     GG <- rbind(
       c(daabb, -ncaabb, 0),
@@ -96,7 +96,7 @@ jndrot <- function(jnd2xyzres, center = c("mean", "achro"), ref1 = "l", ref2 = "
     RR <- FF %*% GG %*% solve(FF)
 
     res <- sweep(coords, 2, cent, "-")
-    res <- t(apply(res, 1, function(x) RR %*% x))
+    res <- tcrossprod(res, RR)
     # res <- sweep(res, 2, coords['jnd2xyzrrf.achro',], '+')
 
     res <- res[, -dim(res)[2]]
@@ -120,7 +120,7 @@ jndrot <- function(jnd2xyzres, center = c("mean", "achro"), ref1 = "l", ref2 = "
       aa <- vectornorm(coords[grep(paste0("jnd2xyzrrf.", ref1), rownames(coords)), ] -
         cent)
       bb <- vectornorm(axis1)
-      daabb <- sum(aa * bb)
+      daabb <- drop(crossprod(aa, bb))
       ncaabb <- vectormag(vectorcross(aa, bb))
       GG <- rbind(
         c(daabb, -ncaabb, 0),
@@ -136,7 +136,7 @@ jndrot <- function(jnd2xyzres, center = c("mean", "achro"), ref1 = "l", ref2 = "
       RR <- FF %*% GG %*% solve(FF)
 
       res <- sweep(coords, 2, cent, "-")
-      res <- t(apply(res, 1, function(x) RR %*% x))
+      res <- tcrossprod(res, RR)
       # res <- sweep(res, 2, coords['jnd2xyzrrf.achro',], '+')
     } else {
       res <- coords
@@ -154,7 +154,7 @@ jndrot <- function(jnd2xyzres, center = c("mean", "achro"), ref1 = "l", ref2 = "
       aa <- vectornorm(res[grep(paste0("jnd2xyzrrf.", ref2), rownames(res)), ] -
         cent)
       bb <- vectornorm(axis2)
-      daabb <- sum(aa * bb)
+      daabb <- drop(crossprod(aa, bb))
       ncaabb <- vectormag(vectorcross(aa, bb))
       GG <- rbind(
         c(daabb, -ncaabb, 0),
@@ -170,7 +170,7 @@ jndrot <- function(jnd2xyzres, center = c("mean", "achro"), ref1 = "l", ref2 = "
       RR <- FF %*% GG %*% solve(FF)
 
       res <- sweep(res, 2, cent, "-")
-      res <- t(apply(res, 1, function(x) RR %*% x))
+      res <- tcrossprod(res, RR)
       # res <- sweep(res, 2, coords['jnd2xyzrrf.achro',], '+')
     }
 
