@@ -2,27 +2,33 @@
 #'
 #' Produces a static 3D tetrahedral plot.
 #'
-#' @param tcsdata (required) a data frame, possibly a result from the [colspace()]
-#' or [tcspace()] function, containing values for the 'x', 'y' and 'z'
-#' coordinates as columns (labeled as such).
+#' @param tcsdata (required) a data frame, possibly a result from the
+#'   [colspace()] or [tcspace()] function, containing values for the 'x', 'y'
+#'   and 'z' coordinates as columns (labeled as such).
 #' @param theta angle to rotate the plot in the xy plane (defaults to 45).
 #' @param phi angle to rotate the plot in the yz plane (defaults to 10).
-#' @param perspective logical, should perspective be forced by using point size to reflect
-#' distance from the plane of view? (defaults to `FALSE``)
-#' @param range, vert.range multiplier applied to `cex` and `vert.cex`, respectively,
-#' to indicate the size range variation reflecting the distance from the plane of view.
+#' @param perspective logical, should perspective be forced by using point size
+#'   to reflect distance from the plane of view? (defaults to `FALSE``)
+#' @param range, vert.range multiplier applied to `cex` and `vert.cex`,
+#'   respectively, to indicate the size range variation reflecting the distance
+#'   from the plane of view.
 #' @param r the distance of the eyepoint from the center of the plotting box.
-#' Very high values approximate an orthographic projection (defaults to 1e6).
-#' See [persp()] for details.
-#' @param zoom zooms in (values greater than 1) or out (values between 0 and 1) from the plotting area.
-#' @param achro.line logical. Should the achromatic line be plotted? (defaults to `FALSE`)
-#' @param achro.lwd,achro.lty graphical parameters for the achromatic coordinates.
-#' @param tetrahedron logical. Should the tetrahedron be plotted? (defaults to `TRUE`)
+#'   Very high values approximate an orthographic projection (defaults to 1e6).
+#'   See [persp()] for details.
+#' @param zoom zooms in (values greater than 1) or out (values between 0 and 1)
+#'   from the plotting area.
+#' @param achro.line logical. Should the achromatic line be plotted? (defaults
+#'   to `FALSE`)
+#' @param achro.lwd,achro.lty graphical parameters for the achromatic
+#'   coordinates.
+#' @param tetrahedron logical. Should the tetrahedron be plotted? (defaults to
+#'   `TRUE`)
 #' @param vert.cex size of the points at the vertices (defaults to 1).
 #' @param out.lwd,out.lcol graphical parameters for the tetrahedral outline.
-#' @param margin vector of four numbers specifying drawing margins (defaults to c(0, 0, 0, 0)).
-#' @param type accepts a vector of length 1 or 2 with 'p' for points and/or 'l' for lines from the point to
-#' the base of the tetrahedron.
+#' @param margin vector of four numbers specifying drawing margins (defaults to
+#'   c(0, 0, 0, 0)).
+#' @param type accepts a vector of length 1 or 2 with 'p' for points and/or 'l'
+#'   for lines from the point to the base of the tetrahedron.
 
 #' @inheritParams triplot
 #'
@@ -37,7 +43,7 @@
 #' plot(tcs.sicalis)
 #' @author Rafael Maia \email{rm72@@zips.uakron.edu}
 #' @author Thomas White \email{thomas.white026@@gmail.com}
-#' @author Chad Eliason \email{cme16@zips.uakron.edu}
+#' @author Chad Eliason \email{cme16@@zips.uakron.edu}
 #'
 #' @export
 #'
@@ -48,10 +54,11 @@
 #' @importFrom plot3D perspbox
 #'
 #' @references Stoddard, M. C., & Prum, R. O. (2008). Evolution of avian plumage
-#'  color in a tetrahedral color space: A phylogenetic analysis of new world buntings.
-#'  The American Naturalist, 171(6), 755-776.
-#' @references Endler, J. A., & Mielke, P. (2005). Comparing entire colour patterns
-#'  as birds see them. Biological Journal Of The Linnean Society, 86(4), 405-431.
+#'   color in a tetrahedral color space: A phylogenetic analysis of new world
+#'   buntings. The American Naturalist, 171(6), 755-776.
+#' @references Endler, J. A., & Mielke, P. (2005). Comparing entire colour
+#'   patterns as birds see them. Biological Journal Of The Linnean Society,
+#'   86(4), 405-431.
 
 tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
                       range = c(1, 2), r = 1e6, zoom = 1,
@@ -239,7 +246,7 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
 
     # sort segments by proximity
     combdist <- setNames(
-      apply(combn(dvals[c("u", "s", "m", "l")], 2), 2, sum),
+      colSums(combn(dvals[c("u", "s", "m", "l")], 2)),
       apply(combn(names(dvals[c("u", "s", "m", "l")]), 2), 2, paste0, collapse = "")
     )
 
