@@ -36,9 +36,18 @@ test_that("summary.rspec", {
   # Different wl ranges
   expect_warning(summary(sicalis, wlmin = 500), "wavelength range not between")
   expect_warning(summary(sicalis[1:200, ]), "wavelength range not between")
+  expect_warning(summary(sicalis, wlmax = 600), "wavelength range not between")
+  expect_error(summary(sicalis, wlmin = 200), "wlmin is smaller")
   expect_error(summary(sicalis, wlmax = 1000), "wlmax is larger")
 
   # Test one spectrum rspec object
   one_spec <- sicalis[, c(1, 2)]
   expect_equal(dim(summary(one_spec)), c(1, 23))
+  expect_length(summary(one_spec, wlmin = 500), 23)
+
+  # Error if subset vars do not exist
+  expect_error(summary(sicalis, subset = "H9"), "do not match color variable names")
+
+  # Warning about UV variables if full UV range is not included
+  expect_warning(summary(sicalis, wlmin = 350), "UV-related variables may not be meaningful")
 })
