@@ -26,7 +26,6 @@ test_that("Receptor orders/names", {
   expect_warning({
     sumtcs <- summary(tetra.space, by = 3)
   })
-  # expect_equal(digest::sha1(sumtcs, digits = 4), "2a4f6b9dcb757139c3c6d2436d6e2a1d27a2d41d")
 })
 
 test_that("Relative quantum catches", {
@@ -144,37 +143,20 @@ test_that("Errors/messages", {
   vis.flowers <- vismodel(flowers, visual = "apis", relative = TRUE, qcatch = "Ei", vonkries = TRUE)
   class(vis.flowers) <- "data.frame"
   expect_error(colspace(vis.flowers, space = "hexagon"), "relative")
-  
+
   # tcs
   vis.flowers <- vismodel(flowers, visual = "apis")
-  expect_error(colspace(vis.flowers, space = 'tcs'), 'not tetrachromatic')
-  expect_warning(colspace(vismodel(flowers, visual = sensmodel(c(300, 400, 500, 600, 700))), space = 'tcs'), 'not tetrachromatic')
-  class(vis.flowers) <- 'data.frame'
-  expect_error(colspace(vis.flowers[1:3], space = 'tcs'), 'has fewer than four')
-  expect_warning(colspace(vis.flowers, space = 'tcs'), 'treating columns as')
-  expect_warning(colspace(cbind(vis.flowers, vis.flowers[1:2]), space = 'tcs'), 'has more than four columns')
-  
+  expect_error(colspace(vis.flowers, space = "tcs"), "not tetrachromatic")
+  expect_warning(colspace(vismodel(flowers, visual = sensmodel(c(300, 400, 500, 600, 700))), space = "tcs"), "not tetrachromatic")
+  class(vis.flowers) <- "data.frame"
+  expect_error(colspace(vis.flowers[1:3], space = "tcs"), "has fewer than four")
+  expect_warning(colspace(vis.flowers, space = "tcs"), "treating columns as")
+  expect_warning(colspace(cbind(vis.flowers, vis.flowers[1:2]), space = "tcs"), "has more than four columns")
+
   vis.flowers <- vismodel(flowers, visual = "bluetit")
-  names(vis.flowers) <- c('a', 'b', 'c', 'd', 'e')
-  expect_warning(colspace(vis.flowers, space = 'tcs'), 'Could not find columns')
-})
+  names(vis.flowers) <- c("a", "b", "c", "d", "e")
+  expect_warning(colspace(vis.flowers, space = "tcs"), "Could not find columns")
 
-test_that("Output regression", {
-  library(digest)
-  data(flowers)
-
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "canis", achromatic = "all")), digits = 4), "786b890b13c01c79f545acea59e04597f4757ddd") # dispace
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "apis", achromatic = "l")), digits = 4), "b6e9903af99aa8b6dab9aa6e8e5e5954a6f16bb1") # trispace
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "bluetit", achromatic = "ch.dc")), digits = 4), "f7b2fdc06e9e3d6597011aa05a654a79b306c03e") # tcs
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "musca", achro = "md.r1"), space = "categorical"), digits = 4), "5defb10dbb4f988431a2e706025aa613448220ec") # categorical
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "segment", achromatic = "bt.dc"), space = "segment"), digits = 4), "0fe76c8979e1cf37d33763d036e1c125270aa2bb") # segment
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "apis", relative = FALSE, qcatch = "Ei", vonkries = TRUE, achromatic = "l"), space = "coc"), digits = 4), "2c2afbdc41577ba095cf6879cfac157315a65afe") # coc
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "apis", qcatch = "Ei", vonkries = TRUE, relative = FALSE, achromatic = "l"), space = "hexagon"), digits = 4), "20ce621deff5b1bf62134f585daaf9941af631eb") # hexagon
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "cie10"), space = "ciexyz"), digits = 4), "ab8b1f06949fc1f5ee5263c557f317a33b66515e") # ciexyz
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "cie10"), space = "cielab"), digits = 4), "21bfa24aadddb421c1af706b75042fd6703f5610") # cielab
-  expect_equal(digest::sha1(colspace(vismodel(flowers, visual = "cie10"), space = "cielch"), digits = 4), "395817a5a0a2d5a3469c39595787738020e66f57") # cielch
-
-  expect_equal(digest::sha1(summary(colspace(vismodel(flowers, visual = "cie10"), space = "cielch")), digits = 4), "8d9c05ec7ae28b219c4c56edbce6a721bd68af82")
   expect_equivalent(round(sum(summary(colspace(vismodel(flowers)))), 5), 4.08984)
   expect_equivalent(round(sum(summary(colspace(vismodel(flowers))), by = 3), 5), 7.08984)
 })
